==> Lingua-TH-Numbers-1.0.7.tar.gz: Lingua-TH-Numbers-1.0.7/README.md <==
Lingua-TH-Numbers
=================

[![Build Status](https://travis-ci.org/guillaumeaubert/Lingua-TH-Numbers.png?branch=master)](https://travis-ci.org/guillaumeaubert/Lingua-TH-Numbers)

Lingua-TH-Numbers offers an object oriented package to convert between Thai and
Arabic numerals, as well as spell numbers in Thai.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc Lingua::TH::Numbers


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/Lingua-TH-Numbers/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/Lingua-TH-Numbers)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/Lingua-TH-Numbers)

 * [MetaCPAN]
   (https://metacpan.org/release/Lingua-TH-Numbers)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2011-2013 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/

==> Lingua-TH-Numbers-v1.0.8.tar.gz: Lingua-TH-Numbers-v1.0.8/README.md <==
Lingua-TH-Numbers
=================

[![Build Status](https://travis-ci.org/guillaumeaubert/Lingua-TH-Numbers.png?branch=master)](https://travis-ci.org/guillaumeaubert/Lingua-TH-Numbers)
[![Coverage Status](https://coveralls.io/repos/guillaumeaubert/Lingua-TH-Numbers/badge.png?branch=master)](https://coveralls.io/r/guillaumeaubert/Lingua-TH-Numbers?branch=master)

Lingua-TH-Numbers offers an object oriented package to convert between Thai and
Arabic numerals, as well as spell numbers in Thai.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc Lingua::TH::Numbers


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/Lingua-TH-Numbers/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/Lingua-TH-Numbers)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/Lingua-TH-Numbers)

 * [MetaCPAN]
   (https://metacpan.org/release/Lingua-TH-Numbers)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2011-2014 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/
